==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/fi_FI.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Yhteystiedot",
"Save" => "Tallenna",
"Uploading..." => "Lähetetään...",
"Importing..." => "Tuodaan...",
"Preparing..." => "Valmistellaan...",
"Imported {count} of {total} contacts" => "Tuotiin {count}/{total} yhteystietoa",
"Imported {imported} contacts. {failed} failed." => "Tuotiin {imported} yhteystietoa. {failed} epäonnistui.",
"An address book called {name} already exists" => "Osoitekirja nimeltä {name} on jo olemassa",
"Failed adding address book: {error}" => "Osoitekirjan lisääminen epäonnistui: {error}",
"Failed loading address books: {error}" => "Osoitekirjojen lataaminen epäonnistui: {error}",
"Indexing contacts" => "Indeksoidaan yhteystietoja",
"Error." => "Virhe.",
"Add to..." => "Lisää...",
"Remove from..." => "Poista...",
"Add group..." => "Lisää ryhmä...",
"Invalid URL: \"{url}\"" => "Virheellinen verkko-osoite: \"{url}\"",
"Invalid email: \"{url}\"" => "Virheellinen sähköposti: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Yhdistäminen epäonnistui. Yhteystietoa ei löydy: {id}",
"Merge failed." => "Yhdistäminen epäonnistui.",
"Merge failed. Error saving contact." => "Yhdistäminen epäonnistui. Virhe yhteystietoa tallentaessa.",
"Select photo" => "Valitse valokuva",
"Network or server error. Please inform administrator." => "Verkko- tai palvelinvirhe. Ilmoita asiasta pääkäyttäjälle.",
"Error adding to group." => "Virhe ryhmään lisättäessä.",
"Error removing from group." => "Virhe poistaessa ryhmästä.",
"Merge contacts" => "Yhdistä yhteystiedot",
"Cancel" => "Peru",
"Add group" => "Lisää ryhmä",
"OK" => "OK",
"Could not find contact: {id}" => "Yhteystietoa ei löydy: {id}",
"No files selected for upload." => "Tiedostoja ei ole valittu lähetettäväksi.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Tiedosto, jota yrität ladata ylittää suurimman sallitun koon tällä palvelimella.",
"Edit profile picture" => "Muokkaa profiilikuvaa",
"Crop photo" => "Rajaa valokuva",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Jotkin yhteystiedot on merkitty poistettaviksi, mutta niitä ei ole vielä poistettu. Odota hetki, että kyseiset yhteystiedot poistetaan.",
"Add" => "Lisää",
"Contact is already in this group." => "Yhteystieto on jo tässä ryhmässä.",
"Contacts are already in this group." => "Yhteystiedot ovat jo tässä ryhmässä.",
"Contact is not in this group." => "Yhteystieto ei ole tässä ryhmässä.",
"Failed renaming group: {error}" => "Ryhmän nimen muuttaminen epäonnistui: {error}",
"A group named {group} already exists" => "Ryhmä nimeltä {group} on jo olemassa",
"You can drag groups to\narrange them as you like." => "Voit raahata ryhmiä järjestääksesi\nne haluamallasi tavalla.",
"Failed adding group: {error}" => "Virhe ryhmää lisätessä: {error}",
"All" => "Kaikki",
"Favorites" => "Suosikit",
"Shared by {owner}" => "Jakanut {owner}",
"Not grouped" => "Ei ryhmitelty",
"Failed loading groups: {error}" => "Ryhmien lataaminen epäonnistui: {error}",
"Please choose the addressbook" => "Valitse osoitekirja",
"Import into..." => "Tuo..",
"Import" => "Tuo",
"Import done" => "Tuonti valmis",
"Close" => "Sulje",
"Error" => "Virhe",
"Displayname cannot be empty." => "Näyttönimi ei voi olla tyhjä.",
"Show CardDav link" => "Näytä CardDav-linkki",
"Show read-only VCF link" => "Näytä vain luku -muodossa oleva VCF-linkki",
"Download" => "Lataa",
"Edit" => "Muokkaa",
"Delete" => "Poista",
"More..." => "Lisää...",
"Less..." => "Vähemmän...",
"Server error! Please inform system administator" => "Palvelinvirhe! Ilmoita asiasta ylläpitäjälle",
"Failed loading photo: {error}" => "Kuvan lataaminen epäonnistui: {error}",
"Contact not found" => "Yhteystietoa ei löydy",
"You do not have permissions to see these contacts" => "Käyttöoikeutesi eivät riitä näiden yhteystietojen katselemiseen",
"You do not have permissions add contacts to the address book" => "Oikeutesi eivät riitä yhteystietojen lisäämiseen osoitekirjaan",
"You do not have permissions to delete this contact" => "Oikeutesi eivät riitä tämän yhteystiedon poistamiseen",
"Unknown error" => "Tuntematon virhe",
"You don't have permissions to update the address book." => "Oikeutesi eivät riitä tämän osoitekirjan päivittämiseen.",
"You don't have permissions to delete the address book." => "Oikeutesi eivät riitä tämän osoitekirjan poistamiseen.",
"Address book not found" => "Osoitekirjaa ei löytynyt",
"You do not have permissions to see this contact" => "Oikeutesi eivät riitä tämän yhteystiedon katseluun",
"You do not have permissions to update this contact" => "Oikeutesi eivät riitä tämän yhteystiedon päivittämiseen",
"Property not found" => "Ominaisuutta ei löydy",
"Unknown IM: " => "Tuntematon IM-arvo.",
"{name}'s Birthday" => "Henkilön {name} syntymäpäivä",
"Error creating address book" => "Virhe osoitekirjaa luotaessa",
"Error updating address book" => "Virhe osoitekirjaa päivittäessä",
"You do not have permissions to delete the \"%s\" address book" => "Käyttöoikeutesi eivät riitä osoitekirjan \"%s\" poistamiseen",
"Error deleting address book" => "Virhe osoitekirjaa poistaessa",
"Error creating contact." => "Virhe yhteystietoa luotaessa.",
"Error deleting contact." => "Virhe yhteystietoa poistaessa.",
"Error saving contact." => "Virhe yhteystietoa tallennettaessa.",
"Information about vCard is incorrect. Please reload the page." => "vCardin tiedot eivät kelpaa. Lataa sivu uudelleen.",
"Error updating contact" => "Virhe yhteystietoa päivittäessä",
"Error getting user photo" => "Virhe hankkiessa kuvaa ",
"No file was uploaded. Unknown error" => "Tiedostoa ei lähetetty. Tuntematon virhe",
"There is no error, the file uploaded with success" => "Ei virheitä, tiedosto lähetettiin onnistuneesti",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Lähetetty tiedosto ylittää upload_max_filesize-arvon rajan php.ini-tiedostossa",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Ladattavan tiedoston maksimikoko ylittää MAX_FILE_SIZE dirketiivin, joka on määritelty HTML-lomakkeessa",
"The uploaded file was only partially uploaded" => "Tiedoston lähetys onnistui vain osittain",
"No file was uploaded" => "Yhtäkään tiedostoa ei lähetetty",
"Missing a temporary folder" => "Tilapäiskansio puuttuu",
"Couldn't load temporary image: " => "Väliaikaiskuvan lataus epäonnistui:",
"Couldn't save temporary image: " => "Väliaikaiskuvan tallennus epäonnistui:",
"No photo path was submitted." => "Kuvan polkua ei annettu.",
"File doesn't exist:" => "Tiedostoa ei ole olemassa",
"Error loading image." => "Virhe kuvaa ladatessa.",
"Image has been removed from cache" => "Kuva on poistettu välimuistista",
"Error creating temporary image" => "Virhe luotaessa väliaikaista kuvaa",
"Error cropping image" => "Virhe rajatessa kuvaa",
"Error resizing image" => "Virhe asettaessa kuvaa uuteen kokoon",
"Error getting PHOTO property." => "Virhe KUVA ominaisuuden saamisessa.",
"Error renaming group." => "Virhe muuttaessa ryhmän nimeä.",
"Failed to write to disk" => "Levylle kirjoitus epäonnistui",
"Not enough storage available" => "Tallennustilaa ei ole riittävästi käytettävissä",
"Error uploading contacts to storage." => "Virhe yhteystietojen lataamisessa talletettavaksi.",
"You do not have permissions to import into this address book." => "Sinulla ei ole oikeuksia tuoda tähän osoitekirjaan.",
"File name missing from request." => "Tiedoston nimi puuttuu pyynnöstä.",
"No value is given." => "Arvoa ei ole annettu.",
"Contact" => "Yhteystieto",
"Other" => "Muu",
"HomePage" => "Kotisivu",
"Jabber" => "Jabber",
"Internet call" => "Internet-puhelu",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "Google Talk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Työ",
"Home" => "Koti",
"Mobile" => "Mobiili",
"Text" => "Teksti",
"Voice" => "Ääni",
"Message" => "Viesti",
"Fax" => "Faksi",
"Video" => "Video",
"Pager" => "Hakulaite",
"Internet" => "Internet",
"Friends" => "Kaverit",
"Family" => "Perhe",
"New Contact" => "Uusi yhteystieto",
"Group name" => "Ryhmän nimi",
"New Group" => "Uusi ryhmä",
"Address books" => "Osoitekirjat",
"Display name" => "Näyttönimi",
"Add Address Book" => "Lisää osoitekirja",
"Select file..." => "Valitse tiedosto...",
"Sort order" => "Lajittelujärjestys",
"First- Lastname" => "Etu-/sukunimi",
"Last-, Firstname" => "Suku-/etunimi",
"Groups" => "Ryhmät",
"Keyboard shortcuts" => "Pikanäppäimet",
"Navigation" => "Suunnistus",
"Next contact in list" => "Seuraava yhteystieto luettelossa",
"Previous contact in list" => "Edellinen yhteystieto luettelossa",
"Expand/collapse current addressbook" => "Laajenna/supista nykyinen osoitekirja",
"Next addressbook" => "Seuraava osoitekirja",
"Previous addressbook" => "Edellinen osoitekirja",
"Actions" => "Toiminnot",
"Refresh contacts list" => "Päivitä yhteystietoluettelo",
"Add new contact" => "Lisää uusi yhteystieto",
"Add new addressbook" => "Lisää uusi osoitekirja",
"Delete current contact" => "Poista nykyinen yhteystieto",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>Osoitekirjassasi ei ole yhteystietoja, tai osoitekirja on poistettu käytöstä.</h3><p>Lisää uusia yhteystietoja, tai tuo yhteystietoja VCF-tiedostosta.</p>",
"Add contact" => "Lisää yhteystieto",
"Delete group" => "Poista ryhmä",
"Rename group" => "Muuta ryhmän nimi",
"Compose mail" => "Lähetä sähköpostia",
"Delete current photo" => "Poista nykyinen valokuva",
"Edit current photo" => "Muokkaa nykyistä valokuvaa",
"Upload new photo" => "Lähetä uusi valokuva",
"Select photo from ownCloud" => "Valitse valokuva ownCloudista",
"Name" => "Nimi",
"First name" => "Etunimi",
"Additional names" => "Lisänimet",
"Last name" => "Sukunimi",
"Select groups" => "Valitse ryhmät",
"Select address book" => "Valitse osoitekirja",
"Nickname" => "Kutsumanimi",
"Enter nickname" => "Anna kutsumanimi",
"Title" => "Otsikko",
"Organization" => "Organisaatio",
"Birthday" => "Syntymäpäivä",
"Notes go here..." => "Muistiinpanot kuuluvat tähän...",
"Export as VCF" => "Vie VCF-muodossa",
"Add field..." => "Lisää kenttä...",
"Phone" => "Puhelin",
"Email" => "Sähköpostiosoite",
"Instant Messaging" => "Pikaviestintä",
"Address" => "Osoite",
"Note" => "Muistio",
"Web site" => "Verkkosivu",
"Delete contact" => "Poista yhteystieto",
"Preferred" => "Ensisijainen",
"Please specify a valid email address." => "Anna kelvollinen sähköpostiosoite.",
"Mail to address" => "Lähetä sähköpostia",
"Delete email address" => "Poista sähköpostiosoite",
"Enter phone number" => "Anna puhelinnumero",
"Delete phone number" => "Poista puhelinnumero",
"Go to web site" => "Siirry verkkosivulle",
"View on map" => "Näytä kartalla",
"Delete address" => "Poista osoite",
"Street address" => "Katuosoite",
"Postal code" => "Postinumero",
"City" => "Paikkakunta",
"Country" => "Maa",
"Instant Messenger" => "Pikaviestin",
"Delete IM" => "Poista IM",
"Active" => "Aktiivinen",
"Share" => "Jaa",
"Export" => "Vie",
"CardDAV link" => "CardDAV-linkki",
"CardDAV syncing addresses" => "CardDAV-synkronointiosoitteet",
"more info" => "lisätietoja",
"Primary address (Kontact et al)" => "Varsinainen osoite (yhteystiedot jne.)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Osoitekirjat",
"New Address Book" => "Uusi osoitekirja",
"Description" => "Kuvaus"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/fi_FI.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Yhteystiedot",
"Add new LDAP Addressbook" => "Lisää uusi LDAP-osoitekirja",
"Ok" => "Ok",
"Cancel" => "Peru",
"Save" => "Tallenna",
"Edit Addressbook" => "Muokkaa osoitekirjaa",
"Starting file import" => "Aloitetaan tiedoston tuominen",
"Format selected: {format}" => "Muoto valittu: {format}",
"Automatic format detection" => "Automaattinen muodon havaitseminen",
"Processing {count}/{total} cards" => "Työstetään {count}/{total} korttia",
"Total:{total}, Success:{imported}, Errors:{failed}" => "Yhteensä:{total}, onnistui:{imported}, virheitä:{failed}",
"An address book called {name} already exists" => "Osoitekirja nimeltä {name} on jo olemassa",
"Failed adding address book: {error}" => "Osoitekirjan lisääminen epäonnistui: {error}",
"Failed loading address books: {error}" => "Osoitekirjojen lataaminen epäonnistui: {error}",
"Server error! Please inform system administator" => "Palvelinvirhe! Ilmoita asiasta ylläpitäjälle",
"Indexing contacts" => "Indeksoidaan yhteystietoja",
"Error." => "Virhe.",
"Add to..." => "Lisää...",
"Remove from..." => "Poista...",
"Add group..." => "Lisää ryhmä...",
"Invalid URL: \"{url}\"" => "Virheellinen verkko-osoite: \"{url}\"",
"Invalid email: \"{url}\"" => "Virheellinen sähköposti: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Yhdistäminen epäonnistui. Yhteystietoa ei löydy: {id}",
"Merge failed." => "Yhdistäminen epäonnistui.",
"Merge failed. Error saving contact." => "Yhdistäminen epäonnistui. Virhe yhteystietoa tallentaessa.",
"Select photo" => "Valitse valokuva",
"Network or server error. Please inform administrator." => "Verkko- tai palvelinvirhe. Ilmoita asiasta pääkäyttäjälle.",
"Only images can be used as contact photos" => "Vain kuvatiedostoja voi käyttää yhteystietojen kuvina",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "Tiedoston \"{filename}\" koko ylittää sallitus enimmäiskoon {size}",
"Error adding to group." => "Virhe ryhmään lisättäessä.",
"Error removing from group." => "Virhe poistaessa ryhmästä.",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "Olet valinnut yli 300 yhteystietoa.\nTämä johtaa mitä luultavimmin epäonnistumiseen! Napsauta tästä yrittääksesi silti.",
"Merge contacts" => "Yhdistä yhteystiedot",
"Add group" => "Lisää ryhmä",
"OK" => "OK",
"Could not find contact: {id}" => "Yhteystietoa ei löydy: {id}",
"Edit profile picture" => "Muokkaa profiilikuvaa",
"Crop photo" => "Rajaa valokuva",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Jotkin yhteystiedot on merkitty poistettaviksi, mutta niitä ei ole vielä poistettu. Odota hetki, että kyseiset yhteystiedot poistetaan.",
"Add" => "Lisää",
"Contact is already in this group." => "Yhteystieto on jo tässä ryhmässä.",
"Contacts are already in this group." => "Yhteystiedot ovat jo tässä ryhmässä.",
"Contact is not in this group." => "Yhteystieto ei ole tässä ryhmässä.",
"Contacts are not in this group." => "Yhteystiedot eivät ole tässä ryhmässä.",
"A group named \"{group}\" already exists" => "Ryhmä nimeltä \"{group}\" on jo olemassa",
"Failed renaming group: {error}" => "Ryhmän nimen muuttaminen epäonnistui: {error}",
"You can drag groups to\narrange them as you like." => "Voit raahata ryhmiä järjestääksesi\nne haluamallasi tavalla.",
"Failed adding group: {error}" => "Virhe ryhmää lisätessä: {error}",
"All" => "Kaikki",
"Favorites" => "Suosikit",
"Shared by {owner}" => "Jakanut {owner}",
"Not grouped" => "Ei ryhmitelty",
"Failed loading groups: {error}" => "Ryhmien lataaminen epäonnistui: {error}",
"Please choose the addressbook" => "Valitse osoitekirja",
"Import into..." => "Tuo..",
"Error loading import template" => "Virhe ladattaessa tuontipohjaa",
"Import contacts" => "Tuo yhteystiedot",
"Import" => "Tuo",
"Importing..." => "Tuodaan...",
"Import done" => "Tuonti valmis",
"Close" => "Sulje",
"Error, missing parameters: " => "Virhe, puuttuvat parametrit:",
"Failed loading photo: {error}" => "Kuvan lataaminen epäonnistui: {error}",
"You do not have permissions to see this contact" => "Oikeutesi eivät riitä tämän yhteystiedon katseluun",
"Contact not found" => "Yhteystietoa ei löydy",
"You do not have permissions to see these contacts" => "Käyttöoikeutesi eivät riitä näiden yhteystietojen katselemiseen",
"You do not have permissions add contacts to the address book" => "Oikeutesi eivät riitä yhteystietojen lisäämiseen osoitekirjaan",
"The backend for this address book does not support adding contacts" => "Tämän osoitekirjan taustaosa ei tue yhteystietojen lisäämistä",
"You do not have permissions to delete this contact" => "Oikeutesi eivät riitä tämän yhteystiedon poistamiseen",
"The backend for this address book does not support deleting contacts" => "Tämän osoitekirjan taustaosa ei tue yhteystietojen poistamista",
"Unknown error" => "Tuntematon virhe",
"Access denied" => "Pääsy estetty",
"The backend for this address book does not support updating" => "Tämän osoitekirjan taustaosa ei tue päivittämistä",
"You don't have permissions to delete the address book." => "Oikeutesi eivät riitä tämän osoitekirjan poistamiseen.",
"Address book not found" => "Osoitekirjaa ei löytynyt",
"You do not have permissions to update this contact" => "Oikeutesi eivät riitä tämän yhteystiedon päivittämiseen",
"Property not found" => "Ominaisuutta ei löydy",
"Unknown IM: " => "Tuntematon IM-arvo.",
"{name}'s Birthday" => "Henkilön {name} syntymäpäivä",
"Error creating address book" => "Virhe osoitekirjaa luotaessa",
"You do not have permissions to delete the \"%s\" address book" => "Käyttöoikeutesi eivät riitä osoitekirjan \"%s\" poistamiseen",
"Error deleting address book" => "Virhe osoitekirjaa poistaessa",
"Error creating contact." => "Virhe yhteystietoa luotaessa.",
"Error creating contact" => "Virhe yhteystietoa luotaessa",
"Error deleting contact" => "Virhe yhteystietoa poistaessa",
"Error retrieving contact" => "Virhe yhteystietoa noutaessa",
"Error saving contact" => "Virhe yhteystietoa tallennettaessa",
"Couldn't find contact." => "Yhteystietoa ei löytynyt.",
"Error saving contact to backend." => "Virhe tallennettaessa yhteystietoa taustaosaan.",
"Property name is not set." => "Ominaisuuden nimeä ei ole asetettu.",
"Property checksum is not set." => "Ominaisuuden tarkistesummaa ei ole asetettu.",
"Information about vCard is incorrect. Please reload the page." => "vCardin tiedot eivät kelpaa. Lataa sivu uudelleen.",
"Error updating contact" => "Virhe yhteystietoa päivittäessä",
"Error saving contact to backend" => "Virhe tallennettaessa yhteystietoa taustajärjestelmään",
"Error getting user photo" => "Virhe hankkiessa kuvaa ",
"No photo path was submitted." => "Kuvan polkua ei annettu.",
"Error loading image from cache" => "Virhe ladatessa kuvaa välimuistista",
"Error getting PHOTO property." => "Virhe KUVA ominaisuuden saamisessa.",
"Error saving contact." => "Virhe yhteystietoa tallennettaessa.",
"Error adding group." => "Virhe ryhmää lisättäessä.",
"Error renaming group." => "Virhe muuttaessa ryhmän nimeä.",
"No file was uploaded. Unknown error" => "Tiedostoa ei lähetetty. Tuntematon virhe",
"There is no error, the file uploaded with success" => "Ei virheitä, tiedosto lähetettiin onnistuneesti",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Lähetetty tiedosto ylittää upload_max_filesize-arvon rajan php.ini-tiedostossa",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Ladattavan tiedoston maksimikoko ylittää MAX_FILE_SIZE dirketiivin, joka on määritelty HTML-lomakkeessa",
"The uploaded file was only partially uploaded" => "Tiedoston lähetys onnistui vain osittain",
"No file was uploaded" => "Yhtäkään tiedostoa ei lähetetty",
"Missing a temporary folder" => "Tilapäiskansio puuttuu",
"Failed to write to disk" => "Levylle kirjoitus epäonnistui",
"Not enough storage available" => "Tallennustilaa ei ole riittävästi käytettävissä",
"Error uploading contacts to storage." => "Virhe yhteystietojen lataamisessa talletettavaksi.",
"You do not have permissions to import into this address book." => "Sinulla ei ole oikeuksia tuoda tähän osoitekirjaan.",
"File name missing from request." => "Tiedoston nimi puuttuu pyynnöstä.",
"No value is given." => "Arvoa ei ole annettu.",
"Contact" => "Yhteystieto",
"Other" => "Muu",
"HomePage" => "Kotisivu",
"Jabber" => "Jabber",
"Internet call" => "Internet-puhelu",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "Google Talk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Työ",
"Home" => "Koti",
"Mobile" => "Mobiili",
"Text" => "Teksti",
"Voice" => "Ääni",
"Message" => "Viesti",
"Fax" => "Faksi",
"Video" => "Video",
"Pager" => "Hakulaite",
"Internet" => "Internet",
"Friends" => "Kaverit",
"Family" => "Perhe",
"Enable LDAP Backend" => "Käytä LDAP-taustaosaa",
"Enable LDAP backend for the contacts application" => "Käytä LDAP-taustaosaa yhteystietosovellukselle",
"Warning: LDAP Backend is in beta mode, use with precautions" => "Varoitus: LDAP-taustaosa on beta-tilassa, käytä varoen",
"New contact" => "Uusi yhteystieto",
"Group name" => "Ryhmän nimi",
"New group" => "Uusi ryhmä",
"Address books" => "Osoitekirjat",
"Display name" => "Näyttönimi",
"Add Address Book" => "Lisää osoitekirja",
"Add LDAP Address Book" => "Lisää LDAP-osoitekirja",
"Automatic format" => "Automaattinen muoto",
"Select file..." => "Valitse tiedosto...",
"Sort order" => "Lajittelujärjestys",
"First- Lastname" => "Etu-/sukunimi",
"Last-, Firstname" => "Suku-/etunimi",
"Delete" => "Poista",
"Groups" => "Ryhmät",
"Download" => "Lataa",
"Merge" => "Yhdistä",
"Email" => "Sähköpostiosoite",
"Phone" => "Puhelin",
"Address" => "Osoite",
"Group" => "Ryhmä",
"Keyboard shortcuts" => "Pikanäppäimet",
"Navigation" => "Suunnistus",
"Next contact in list" => "Seuraava yhteystieto luettelossa",
"Previous contact in list" => "Edellinen yhteystieto luettelossa",
"Expand/collapse current addressbook" => "Laajenna/supista nykyinen osoitekirja",
"Next addressbook" => "Seuraava osoitekirja",
"Previous addressbook" => "Edellinen osoitekirja",
"Actions" => "Toiminnot",
"Refresh contacts list" => "Päivitä yhteystietoluettelo",
"Add new contact" => "Lisää uusi yhteystieto",
"Add new addressbook" => "Lisää uusi osoitekirja",
"Delete current contact" => "Poista nykyinen yhteystieto",
"You have no contacts in your address book or your address book is disabled." => "Osoitekirjassasi ei ole yhteystietoja, tai osoitekirjasi on pois käytöstä.",
"Add a new contact or import existing contacts from a VCF file." => "Lisää uusi yhteystieto tai tuo olemassa olevia yhteystietoja VCF-tiedostosta.",
"Which contact should the data be merged into?" => "Mihin yhteystietoon tiedot tulee yhdistää?",
"Delete the other(s) after successful merge?" => "Poistetaanko muut onnistuneen yhdistämisen jälkeen?",
"Compose mail" => "Lähetä sähköpostia",
"Delete current photo" => "Poista nykyinen valokuva",
"Edit current photo" => "Muokkaa nykyistä valokuvaa",
"Upload new photo" => "Lähetä uusi valokuva",
"Select photo from Files" => "Valitse kuva tiedostoista",
"Favorite" => "Suosikki",
"Name" => "Nimi",
"First name" => "Etunimi",
"Additional names" => "Lisänimet",
"Last name" => "Sukunimi",
"Address book" => "Osoitekirja",
"Nickname" => "Kutsumanimi",
"Title" => "Otsikko",
"Organization" => "Organisaatio",
"Birthday" => "Syntymäpäivä",
"Website" => "Verkkosivusto",
"Instant messaging" => "Pikaviestintä",
"Notes go here..." => "Muistiinpanot kuuluvat tähän...",
"Add field..." => "Lisää kenttä...",
"Instant Messaging" => "Pikaviestintä",
"Note" => "Muistio",
"Web site" => "Verkkosivu",
"Preferred" => "Ensisijainen",
"Please specify a valid email address." => "Anna kelvollinen sähköpostiosoite.",
"someone@example.com" => "esimerkki@osoite.fi",
"Mail to address" => "Lähetä sähköpostia",
"Delete email address" => "Poista sähköpostiosoite",
"Enter phone number" => "Anna puhelinnumero",
"Go to web site" => "Siirry verkkosivulle",
"View on map" => "Näytä kartalla",
"Street address" => "Katuosoite",
"Postal code" => "Postinumero",
"City" => "Paikkakunta",
"Country" => "Maa",
"Instant Messenger" => "Pikaviestin",
"Active" => "Aktiivinen",
"Share" => "Jaa",
"Export" => "Vie",
"CardDAV link" => "CardDAV-linkki",
"Edit" => "Muokkaa",
"Description" => "Kuvaus",
"LDAP URL" => "LDAP-osoite",
"Read-only" => "Vain luku",
"Read-Only" => "Vain luku",
"User" => "Käyttäjä",
"Password" => "Salasana",
"Base DN" => "Oletus DN"
);
